# i asked chatgpt to generate brainrot and this is what it gave... pls dont ask
quotes = [
    "Invest in {stock}? Fam, that’s more sus than MrBeast at 3 AM 💀💀💀.",
    "Bruh, if {stock} tanks, just know… I’m in sturdy mode with my diamond hands 🗿✨ #HoldTheLine.",
    "They say {stock} is ‘to the moon’ but blud, it’s giving Ohio energy frfr 😭💀.",
    "{stock} is up? Blud, that’s some sigma grindset vibes. Down? It’s Quandale Dingle levels of L ☠️💀.",
    "Buying {stock} is like saying ‘womp womp’ to financial sanity 💀💀. Good luck, fam.",
    "In {stock} we don’t trust… unless it’s giving Kai Cenat rizz levels 🌚🚀. Otherwise? Pure L energy.",
    "If {stock} goes up, I'm living my Patrick Bateman fantasy. If it tanks, I’m cooked like EDP445 in Ohio ☠️☠️.",
    "{stock} to the moon? Nah fam, we’re in the skibidi toilet 🚽 vibes with this one 💀.",
    "The way {stock} be moving… it’s straight up a Roblox obby for my portfolio. Those who know, know 💀☠️😭.",
    "Bruh, {stock} is either gonna hit prime looksmaxxing or it’s a one-way ticket to the shadow realm 🍷🗿.",
    "Investing in {stock} is just a sussy baka move 🗿💀, like, are you even sturdy?",
    "Bro’s going all-in on {stock} like it’s Ice Spice in Ambatukam mode 🍷😭. We gonna need a miracle.",
    "Just bought {stock} because I saw it trending on TikTok. It’s either L gyatt or W edge… let’s see 😭💀.",
    "{stock} stock is so cooked it’s practically Adin Ross at the skibidi toilet 💀. Sussy vibes only.",
    "They say ‘buy low, sell high,’ but like… {stock} out here playing full-on sus games 😭😭.",
    "{stock}: Not sure if it’s prime looksmaxxed or if it’s cooked harder than Quandale Dingle’s rizz ☠️.",
    "Lowkey, {stock} just pulled a Blue Tie Kid on my portfolio… that ain’t sturdy 💀💀.",
    "{stock} stock: for the true gooners and sigma grinders 💀. Hold if you dare, blud.",
    "{stock} is up and down like Adin Ross at 3 AM… not sure if we’re in sturdy mode or cooked 🗿🍷.",
    "Bruh, investing in {stock} is like throwing bags at Kai Cenat’s Costco. Risky vibes only, fam 💀💀.",
    "{stock} is either gonna gyatt or bomboclat my portfolio. We’re costco guys… let’s get sturdy 🍷🗿.",
    "Bro’s out here gooning on {stock} like it’s the new Grimace shake 💀💀. Either we mog the markets or get cooked like Ohio at 3 AM.",
    "Buying {stock} is me risking it all in full sigma grindset mode. But if it tanks… I’m cooked harder than EDP in Ohio ☠️☠️.",
    "Bruh, if {stock} doesn’t give Baby Gronk x Livee Dunn-levels of gyatt, it’s over… my rizz goes straight to Ligma vibes 💀🍷.",
    "Just threw my bag at {stock} like it’s Livee Dunn in Ambatukam mode 😭. Might mog, might Ligma… either way, sturdy.",
    "Investing in {stock} is basically me live gooning at the edge of my portfolio 🍷🗿. Either full-on W, or sussier than Freddy Fazbear at 3 AM.",
    "{stock} stock is like mewing on steroids – it’s either gonna level up to pure mogging energy, or I’m cooked like Quandale Dingle’s rizz ☠️💀.",
    "Blud, I’m going all in on {stock} like a skibidi toilet level up. If it bombs, we’re Ohio cooked. But if it slaps… full Ligma grindset 💀🍷.",
    "If {stock} doesn’t start moving sturdy, I’m about to send it to the shadow realm. Sigma gooners only out here 🌚💀.",
    "Lowkey, {stock} is like investing in a Grimace shake recipe – it’s either pure rizz mogging the market, or straight to Ohio levels of cringe 💀💀.",
    "Betting on {stock} like it’s the last Grimace shake in Costco. Either we’re skibidi sturdy, or we’re deep in the cringe abyss 🍷😭.",
    "{stock} be on that Sigma grind, mogging everything in its path!",
    "Bruh, {stock} just hit that Level 100 Rizz, skyrocketing like Kai Cenat's viewer count.",
    "Looks like {stock} caught a major skibidi bounce, straight to the moon!",
    "{stock} lowkey mewing its way up, flexing on the Beta stocks below.",
    "Sussy vibes from {stock}, tanking hard like a Grimace Shake gone bad.",
    "{stock} is pulling an Amongus move, sus moves everywhere—are we seeing a dip or a skibidi rise?",
    "Not gonna lie, {stock} just hit Baby Gronk levels of rizz, mad gains incoming.",
    "RIP to the haters, {stock} is mogging on all the cringe stocks with this rally.",
    "Bruh, {stock} went full Ohio mode, can't tell if it's gonna tank or keep gooning up.",
    "{stock} is edging close to a new high, just needs that Sigma push!",
    "{stock} is giving off serious Livee Dunn energy, lifting itself to influencer levels!",
    "Yo, {stock} just paid the Phanum tax, feels like it's on the verge of an epic bounce.",
    "{stock} got that Zuck energy, going steady but packing a surprise skibidi punch soon.",
    "Bruh, {stock} just got hit with some sussy volatility, feeling like an iShowSpeed moment.",
    "Is {stock} mewing up for a breakout or just gooning around at this level?",
    "Not gonna lie, {stock} be acting like an Elon tweet—wild swings but mad potential.",
    "{stock} went from cringe to skibidi in one day; it’s absolutely mogging the haters.",
    "{stock} feeling like an Ohio stock today, unpredictable but giving high Sigma potential.",
    "Bruh, {stock} just got Baby Gronk'd, straight mogging the weak stocks around it.",
    "{stock} looks like it's about to pay the ultimate Phanum tax, might tank soon!"
]
